#!/usr/bin/python
#
# Copyright 2018-2023 Polyaxon, Inc.
# This file and its contents are licensed under the AGPLv3 License.
# Please see the included NOTICE for copyright information and
# LICENSE-AGPL for a copy of the license.

from django.apps import AppConfig


class CommandsConfig(AppConfig):
    name = "haupt.common.commands"
    verbose_name = "commands"
