#!/usr/bin/python
#
# Copyright 2018-2023 Polyaxon, Inc.
# This file and its contents are licensed under the AGPLv3 License.
# Please see the included NOTICE for copyright information and
# LICENSE-AGPL for a copy of the license.

NAME = "haupt"
VERSION = "2.0.0-rc12"
DESC = (
    "Lineage metadata API, artifacts streams, sandbox, ML-API, and spaces for Polyaxon."
)
URL = "https://github.com/polyaxon/haupt"
AUTHOR = "Polyaxon, Inc."
EMAIL = "contact@polyaxon.com"
LICENSE = "AGPLv3"
