#!/usr/bin/python
#
# Copyright 2018-2023 Polyaxon, Inc.
# This file and its contents are licensed under the AGPLv3 License.
# Please see the included NOTICE for copyright information and
# LICENSE-AGPL for a copy of the license.

from haupt.proxies.generators.api import generate_api_conf
from haupt.proxies.generators.forward import generate_forward_proxy_cmd
from haupt.proxies.generators.gateway import generate_gateway_conf
from haupt.proxies.generators.streams import generate_streams_conf
